@@ -1,18 +1,20 @@
 import logging
+import sys
 
-from PyQt5.QtWidgets import QWidget
+from PyQt5.QtWidgets import QWidget, QApplication
 from PyQt5.QtCore import pyqtSlot, QThreadPool
 
 from .wait_window import WaitWindow
 from .tools import Worker
 from .update_version import update_version
 from .check_version import check_outdated, CheckVersionMessage
-from .restart import restart
 
 
 class MainWindow(QWidget):
     log = logging.getLogger(__name__)
 
+    EXIT_CODE_REBOOT: int = -123456789
+
     def __init__(self, version: str):
         super().__init__()
         self.status = CheckVersionMessage.not_checked
@@ -31,13 +33,15 @@ class MainWindow(QWidget):
 
     @pyqtSlot(name='updateVersion')
     def _update_version(self):
-        self.worker = Worker(update_version)
-        self.worker.signals.finished.connect(self._on_updated)
-        self.q_thread_pool.start(self.worker)
+        self.worker1 = Worker(update_version)
+        self.worker1.signals.result.connect(self._on_updated)
+        self.q_thread_pool.start(self.worker1)
 
-    @pyqtSlot(bool, name='onUpdated')
+    @pyqtSlot(object, name='onUpdatedFinished')
     def _on_updated(self, updated: bool):
         if updated:
-            restart()
+            qApp = QApplication.instance()
+            qApp.closeAllWindows()
+            qApp.exit(self.EXIT_CODE_REBOOT)
         else:
             self.wait_window.show_info('Auto update failed. Please, update the program manually.')
